@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -35,7 +35,7 @@ public:
     Q_REQUIRED_RESULT LoggingCategory::LoggingType type() const;
     void setType(LoggingCategory::LoggingType type);
     Q_REQUIRED_RESULT bool loggingCategoryIsNotDefault() const;
-    void setDefaultCategories(const LoggingCategory::LoggingType &defaultCategories);
+    void setDefaultCategories(LoggingCategory::LoggingType defaultCategories);
     Q_REQUIRED_RESULT LoggingCategory::LoggingType defaultCategories() const;
 
     void restoreToDefault();
