@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2019-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -97,7 +97,7 @@ void KDebugSettingsLoadingCategories::readCategoriesFiles(const QString &path)
 
     const QByteArray rulesFilePath = qgetenv("QT_LOGGING_CONF");
     if (!rulesFilePath.isEmpty()) {
-        const QList<KDebugSettingsUtil::LoadLoggingCategory> envCategories = KDebugSettingsUtil::readLoggingQtCategories(QString::fromLatin1(rulesFilePath));
+        //const QList<KDebugSettingsUtil::LoadLoggingCategory> envCategories = KDebugSettingsUtil::readLoggingQtCategories(QString::fromLatin1(rulesFilePath));
         //TODO
     }
 
